@@ -1,4 +1,3 @@
-/* $Xorg: xprint.c,v 1.5 2001/03/05 20:42:26 pookie Exp $ */
 /*
 (c) Copyright 1996 Hewlett-Packard Company
 (c) Copyright 1996 International Business Machines Corp.
@@ -64,13 +63,14 @@ copyright holders.
 **    *********************************************************
 **
 ********************************************************************/
-/* $XFree86: xc/programs/Xserver/Xext/xprint.c,v 1.15 2003/10/28 23:08:44 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/Xext/xprint.c,v 1.18 2006/02/19 15:51:16 tsi Exp $ */
 
+#undef  _XP_PRINT_SERVER_
 #define _XP_PRINT_SERVER_
-#include "X.h"
-#include "Xos.h"
+#include <X11/X.h>
+#include <X11/Xos.h>
 #define NEED_EVENTS
-#include "Xproto.h"
+#include <X11/Xproto.h>
 #undef NEED_EVENTS
 #include "misc.h"
 #include "windowstr.h"
@@ -78,9 +78,9 @@ copyright holders.
 #include "pixmapstr.h"
 #include "extnsionst.h"
 #include "dixstruct.h"
-#include "Xatom.h"
-#include "Print.h"
-#include "Printstr.h"
+#include <X11/Xatom.h>
+#include <X11/extensions/Print.h>
+#include <X11/extensions/Printstr.h>
 #include "../Xprint/DiPrint.h"
 #include "../Xprint/attributes.h"
 #include "modinit.h"
@@ -415,7 +415,8 @@ FreeScreenEntry(XpScreenPtr pScreenEntry)
  * whenever a context gets created for a particular driver on this screen.
  */
 void
-XpRegisterInitFunc(ScreenPtr pScreen, char *driverName, int (*initContext)(struct _XpContext *))
+XpRegisterInitFunc(ScreenPtr pScreen, char *driverName,
+		   int (*initContext)(struct _XpContext *))
 {
     XpDriverPtr pDriver;
 
@@ -568,7 +569,7 @@ ProcXpQueryVersion(ClientPtr client)
 {
     /* REQUEST(xPrintQueryVersionReq); */
     xPrintQueryVersionReply rep;
-    register int n;
+    int n;
     long l;
 
     REQUEST_SIZE_MATCH(xPrintQueryVersionReq);
@@ -1099,8 +1100,8 @@ ProcXpGetContext(ClientPtr client)
     xPrintGetContextReply rep;
 
     XpContextPtr pContext;
-    register int n;
-    register long l;
+    int n;
+    long l;
 
     REQUEST_SIZE_MATCH(xPrintGetContextReq);
 
@@ -1381,11 +1382,11 @@ XpFreePage(pointer data, XID id)
 static void
 InitContextPrivates(XpContextPtr context)
 {
-    register char *ptr;
+    char *ptr;
     DevUnion *ppriv;
-    register unsigned *sizes;
-    register unsigned size;
-    register int i;
+    unsigned *sizes;
+    unsigned size;
+    int i;
 
     if (totalContextSize == sizeof(XpContextRec))
         ppriv = (DevUnion *)NULL;
@@ -1733,9 +1734,7 @@ ProcXpEndDoc(ClientPtr client)
 }
 
 static Bool
-DoStartPage(
-    ClientPtr client,
-    XpStPagePtr c)
+DoStartPage(ClientPtr client, XpStPagePtr c)
 {
     WindowPtr pWin = c->pWin;
     int result = Success;
@@ -2324,7 +2323,7 @@ ProcXpInputSelected(ClientPtr client)
 {
     REQUEST(xPrintInputSelectedReq);
     xPrintInputSelectedReply rep;
-    register int n;
+    int n;
     long l;
     XpClientPtr pXpClient;
     XpContextPtr pContext;
