@@ -1,5 +1,5 @@
 /*
- * $XFree86: xc/programs/Xserver/hw/tinyx/txaa.c,v 1.2 2004/06/23 19:40:15 tsi Exp $
+ * $XFree86: xc/programs/Xserver/hw/tinyx/txaa.c,v 1.3 2005/10/14 15:16:27 tsi Exp $
  *
  * Copyright  2001 Keith Packard, member of The XFree86 Project, Inc.
  *
@@ -69,7 +69,7 @@
  */
 
 #include "tinyx.h"
-#include	"fontstruct.h"
+#include	<X11/fonts/fontstruct.h>
 #include	"dixfontstr.h"
 
 int	kaaGeneration;
