@@ -26,7 +26,7 @@ from The Open Group.
 
 */
 /*
- * Copyright (c) 1994-2004 by The XFree86 Project, Inc.
+ * Copyright (c) 1994-2006 by The XFree86 Project, Inc.
  * All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -81,7 +81,7 @@ from The Open Group.
  *
  */
 
-/* $XFree86: xc/programs/Xserver/hw/vfb/InitOutput.c,v 3.31 2005/01/30 17:48:44 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/vfb/InitOutput.c,v 3.37 2007/04/03 00:21:12 tsi Exp $ */
 
 #if defined(WIN32)
 #include <X11/Xwinsock.h>
@@ -165,7 +165,7 @@ static int vfbNumScreens;
 static vfbScreenInfo vfbScreens[MAXSCREENS];
 static Bool vfbPixmapDepths[33];
 #ifdef HAS_MMAP
-static char *pfbdir = NULL;
+static const char *pfbdir = NULL;
 #endif
 typedef enum { NORMAL_MEMORY_FB, SHARED_MEMORY_FB, MMAPPED_FILE_FB } fbMemType;
 static fbMemType fbmemtype = NORMAL_MEMORY_FB;
@@ -278,15 +278,15 @@ AbortDDX()
 
 #ifdef __DARWIN__
 void
-DarwinHandleGUI(int argc, char *argv[])
+DarwinHandleGUI(int argc, const char *argv[], char *envp[])
 {
 }
 
-void GlxExtensionInit();
+void GlxExtensionInit(INITARGS);
 void GlxWrapInitVisuals(void *procPtr);
 
 void
-DarwinGlxExtensionInit()
+DarwinGlxExtensionInit(INITARGS)
 {
     GlxExtensionInit();
 }
@@ -319,10 +319,8 @@ ddxUseMsg()
 {
     ErrorF("-screen n WxHxD[@x,y]  set screen's width, height, depth, origin\n");
     ErrorF("-pixdepths list-of-int support given pixmap depths\n");
-#ifdef RENDER
     ErrorF("+/-render		   turn on/of RENDER extension support"
 	   "(default on)\n");
-#endif
     ErrorF("-linebias n            adjust thin line pixelization\n");
     ErrorF("-blackpixel n          pixel value for black\n");
     ErrorF("-whitepixel n          pixel value for white\n");
@@ -337,7 +335,7 @@ ddxUseMsg()
 }
 
 int
-ddxProcessArgument(int argc, char *argv[], int i)
+ddxProcessArgument(int argc, const char *argv[], int i)
 {
     static Bool firstTime = TRUE;
 
@@ -351,22 +349,29 @@ ddxProcessArgument(int argc, char *argv[], int i)
     if (strcmp (argv[i], "-screen") == 0)	/* -screen n WxHxD */
     {
 	int screenNum;
+	char *arg2;
  	char *s;
-	if (i + 2 >= argc) UseMsg();
+	if (i + 2 >= argc) return 0;
 	screenNum = atoi(argv[i+1]);
 	if (screenNum < 0 || screenNum >= MAXSCREENS)
 	{
 	    ErrorF("Invalid screen number %d\n", screenNum);
-	    UseMsg();
+	    return 0;
 	}
-	s = strtok(argv[i+2], "@");
+	arg2 = xstrdup(argv[i+2]);
+	if (!arg2) {
+	    ErrorF("Memory allocation error\n");
+	    return 0;
+	}
+	s = strtok(arg2, "@");
 	if (3 != sscanf(s, "%dx%dx%d",
 			&vfbScreens[screenNum].width,
 			&vfbScreens[screenNum].height,
 			&vfbScreens[screenNum].depth))
 	{
+	    xfree(arg2);
 	    ErrorF("Invalid screen configuration %s\n", s);
-	    UseMsg();
+	    return 0;
 	}
 	s = strtok(NULL, "@");
 	if (s)
@@ -375,8 +380,9 @@ ddxProcessArgument(int argc, char *argv[], int i)
 			    &vfbScreens[screenNum].xOrigin,
 			    &vfbScreens[screenNum].yOrigin))
 	    {
+		xfree(arg2);
 		ErrorF("Invalid screen position %s\n", s);
-		UseMsg();
+		return 0;
 	    }
 	}
 	else
@@ -388,6 +394,7 @@ ddxProcessArgument(int argc, char *argv[], int i)
 	if (screenNum >= vfbNumScreens)
 	    vfbNumScreens = screenNum + 1;
 	lastScreen = screenNum;
+	xfree(arg2);
 	return 3;
     }
 
@@ -395,13 +402,13 @@ ddxProcessArgument(int argc, char *argv[], int i)
     {
 	int depth, ret = 1;
 
-	if (++i >= argc) UseMsg();
+	if (++i >= argc) return 0;
 	while ((i < argc) && (depth = atoi(argv[i++])) != 0)
 	{
 	    if (depth < 0 || depth > 32)
 	    {
 		ErrorF("Invalid pixmap depth %d\n", depth);
-		UseMsg();
+		return 0;
 	    }
 	    vfbPixmapDepths[depth] = TRUE;
 	    ret++;
@@ -424,7 +431,7 @@ ddxProcessArgument(int argc, char *argv[], int i)
     if (strcmp (argv[i], "-blackpixel") == 0)	/* -blackpixel n */
     {
 	Pixel pix;
-	if (++i >= argc) UseMsg();
+	if (++i >= argc) return 0;
 	pix = atoi(argv[i]);
 	if (-1 == lastScreen)
 	{
@@ -444,7 +451,7 @@ ddxProcessArgument(int argc, char *argv[], int i)
     if (strcmp (argv[i], "-whitepixel") == 0)	/* -whitepixel n */
     {
 	Pixel pix;
-	if (++i >= argc) UseMsg();
+	if (++i >= argc) return 0;
 	pix = atoi(argv[i]);
 	if (-1 == lastScreen)
 	{
@@ -464,7 +471,7 @@ ddxProcessArgument(int argc, char *argv[], int i)
     if (strcmp (argv[i], "-linebias") == 0)	/* -linebias n */
     {
 	unsigned int linebias;
-	if (++i >= argc) UseMsg();
+	if (++i >= argc) return 0;
 	linebias = atoi(argv[i]);
 	if (-1 == lastScreen)
 	{
@@ -484,7 +491,7 @@ ddxProcessArgument(int argc, char *argv[], int i)
 #ifdef HAS_MMAP
     if (strcmp (argv[i], "-fbdir") == 0)	/* -fbdir directory */
     {
-	if (++i >= argc) UseMsg();
+	if (++i >= argc) return 0;
 	pfbdir = argv[i];
 	fbmemtype = MMAPPED_FILE_FB;
 	return 2;
@@ -975,7 +982,7 @@ vfbCloseScreen(int index, ScreenPtr pScreen)
 }
 
 static Bool
-vfbScreenInit(int index, ScreenPtr pScreen, int argc, char **argv)
+vfbScreenInit(int index, ScreenPtr pScreen, const int argc, const char **argv)
 {
     vfbScreenInfoPtr pvfb = &vfbScreens[index];
     int dpix = 100, dpiy = 100;
@@ -1006,10 +1013,8 @@ vfbScreenInit(int index, ScreenPtr pScreen, int argc, char **argv)
     case 32:
 	ret = fbScreenInit(pScreen, pbits, pvfb->width, pvfb->height,
 			      dpix, dpiy, pvfb->paddedWidth,pvfb->bitsPerPixel);
-#ifdef RENDER
 	if (ret && Render) 
 	    fbPictureInit (pScreen, 0, 0);
-#endif
 	break;
     default:
 	return FALSE;
@@ -1061,7 +1066,7 @@ vfbScreenInit(int index, ScreenPtr pScreen, int argc, char **argv)
 
 
 void
-InitOutput(ScreenInfo *screenInfo, int argc, char **argv)
+InitOutput(ScreenInfo *screenInfo, const int argc, const char **argv)
 {
     int i;
     int NumFormats = 0;
