@@ -1,4 +1,4 @@
-/* $XFree86: xc/programs/Xserver/hw/xfree86/os-support/bus/Pci.c,v 1.101 2008/03/26 19:07:03 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/os-support/bus/Pci.c,v 1.102 2008/04/24 20:54:54 tsi Exp $ */
 /*
  * Pci.c - New server PCI access functions
  *
@@ -1552,13 +1552,6 @@ xf86scanpci(int flags)
     return pci_devp;
 }
 
-CARD32
-pciCheckForBrokenBase(PCITAG Tag,int basereg)
-{
-    pciWriteLong(Tag, PCI_MAP_REG_START + (basereg << 2), 0xffffffff);
-    return pciReadLong(Tag, PCI_MAP_REG_START + (basereg << 2));
-}
-
 #if defined(INCLUDE_XF86_MAP_PCI_MEM)
 
 pointer
