@@ -26,7 +26,7 @@ in this Software without prior written authorization from the copyright holder.
  * Author:  Keith Packard, MIT X Consortium
  */
 
-/* $XFree86: xc/programs/xdm/access.c,v 3.17 2006/01/09 15:01:03 dawes Exp $ */
+/* $XFree86: xc/programs/xdm/access.c,v 3.18 2006/06/28 02:31:48 dawes Exp $ */
 
 /*
  * Access control for XDMCP - keep a database of allowable display addresses
@@ -308,7 +308,7 @@ tryagain:
 	void *addr=NULL;
 	size_t addr_length=0;
 #if defined(IPv6) && defined(AF_INET6)
-	struct addrinfo *ai;
+	struct addrinfo *ai = NULL;
 #else
 	struct hostent  *hostent = gethostbyname (hostOrAlias);
 #endif	
@@ -344,17 +344,26 @@ tryagain:
 	    Debug ("No such host %s\n", hostOrAlias);
 	    LogError ("Access file \"%s\", host \"%s\" not found\n", accessFile, hostOrAlias);
 	    free ((char *) h);
+#if defined(IPv6) && defined(AF_INET6)
+	    if (ai)
+		freeaddrinfo(ai);
+#endif
 	    goto tryagain;
 	}
 	if (!XdmcpAllocARRAY8 (&h->entry.hostAddress, addr_length))
 	{
 	    LogOutOfMem ("ReadHostEntry\n");
 	    free ((char *) h);
+#if defined(IPv6) && defined(AF_INET6)
+	    if (ai)
+		freeaddrinfo(ai);
+#endif
 	    return NULL;
 	}
 	memmove( h->entry.hostAddress.data, addr, addr_length);
 #if defined(IPv6) && defined(AF_INET6)
-	freeaddrinfo(ai);
+	if (ai)
+	    freeaddrinfo(ai);
 #endif
     }
     return h;
@@ -428,7 +437,7 @@ ReadDisplayEntry (FILE *file)
 	    int addrtype = 0;
 
 #if defined(IPv6) && defined(AF_INET6)
-	    struct addrinfo *ai;
+	    struct addrinfo *ai = NULL;
 
 	    if (getaddrinfo(displayOrAlias, NULL, NULL, &ai) == 0) {
 		addrtype = ai->ai_addr->sa_family;
@@ -455,6 +464,10 @@ ReadDisplayEntry (FILE *file)
 	    {
 		LogError ("Access file %s, display %s unknown\n", accessFile, displayOrAlias);
 		free ((char *) d);
+#if defined(IPv6) && defined(AF_INET6)
+		if (ai)
+		    freeaddrinfo(ai);
+#endif
 		return NULL;
 	    }
 	    d->type = DISPLAY_ADDRESS;
@@ -462,9 +475,17 @@ ReadDisplayEntry (FILE *file)
 	    if (!XdmcpAllocARRAY8 (&display->clientAddress, addr_length))
 	    {
 	    	free ((char *) d);
+#if defined(IPv6) && defined(AF_INET6)
+		if (ai)
+		    freeaddrinfo(ai);
+#endif
 	    	return NULL;
 	    }
 	    memmove( display->clientAddress.data, addr, addr_length);
+#if defined(IPv6) && defined(AF_INET6)
+	    if (ai)
+		freeaddrinfo(ai);
+#endif
 	    switch (addrtype)
 	    {
 #ifdef AF_UNIX
